/**
 * @stability stable
 */
export interface ContainerOverride {
    /**
     * Name of the container inside the task definition.
     *
     * @stability stable
     */
    readonly containerName: string;
    /**
     * Command to run inside the container.
     *
     * @default Default command
     * @stability stable
     */
    readonly command?: string[];
    /**
     * Variables to set in the container's environment.
     *
     * @stability stable
     */
    readonly environment?: TaskEnvironmentVariable[];
    /**
     * The number of cpu units reserved for the container.
     *
     * @default The default value from the task definition.
     * @stability stable
     */
    readonly cpu?: number;
    /**
     * Hard memory limit on the container.
     *
     * @default The default value from the task definition.
     * @stability stable
     */
    readonly memoryLimit?: number;
    /**
     * Soft memory limit on the container.
     *
     * @default The default value from the task definition.
     * @stability stable
     */
    readonly memoryReservation?: number;
}
/**
 * An environment variable to be set in the container run as a task.
 *
 * @stability stable
 */
export interface TaskEnvironmentVariable {
    /**
     * Name for the environment variable.
     *
     * Exactly one of `name` and `namePath` must be specified.
     *
     * @stability stable
     */
    readonly name: string;
    /**
     * Value of the environment variable.
     *
     * Exactly one of `value` and `valuePath` must be specified.
     *
     * @stability stable
     */
    readonly value: string;
}
