import * as events from '@aws-cdk/aws-events';
import * as iam from '@aws-cdk/aws-iam';
/**
 * Configuration properties of an Event Bus event.
 *
 * @stability stable
 */
export interface EventBusProps {
    /**
     * Role to be used to publish the event.
     *
     * @default a new role is created.
     * @stability stable
     */
    readonly role?: iam.IRole;
}
/**
 * Notify an existing Event Bus of an event.
 *
 * @stability stable
 */
export declare class EventBus implements events.IRuleTarget {
    private readonly eventBus;
    private readonly role?;
    /**
     * @stability stable
     */
    constructor(eventBus: events.IEventBus, props?: EventBusProps);
    /**
     * Returns the rule target specification.
     *
     * NOTE: Do not use the various `inputXxx` options. They can be set in a call to `addTarget`.
     *
     * @stability stable
     */
    bind(rule: events.IRule, id?: string): events.RuleTargetConfig;
    private putEventStatement;
}
